# eric7.Utilities.__init__

Package implementing various functions/classes needed everywhere within eric.

### Global Attributes

_escape
_escape_map
_uescape
_uunescape
codingBytes_regexps
coding_regexps
configDir
supportedCodecs

### Classes

CodingError | Class implementing an exception, which is raised, if a given coding is incorrect.

### Functions

__showwarning | Module function to raise a SyntaxError for a SyntaxWarning.
_percentReplacementFunc | Protected function called for replacing % codes.
convertLineEnds | Function to convert the end of line characters.
decode | Function to decode some byte text into a string.
decodeBytes | Function to decode some byte text into a string.
decodeString | Function to decode a string containing Unicode encoded characters.
encode | Function to encode text into a byte text.
escape_entities | Function to encode html entities.
escape_uentities | Function to encode html entities.
extractFlags | Function to extract eric specific flags out of the given text.
extractFlagsFromFile | Function to extract eric specific flags out of the given file.
extractLineFlags | Function to extract flags starting and ending with '__' from a line comment.
filterAnsiSequences | Function to filter out ANSI escape sequences (color only).
generateDistroInfo | Module function to generate a string with distribution infos.
generatePluginsVersionInfo | Module function to generate a string with plugins version infos.
generateVersionInfo | Module function to generate a string with various version infos.
getCoverageFileName | Function to build a file name for a coverage data file.
getCoverageFileNames | Function to build a list of coverage data file names.
getPercentReplacement | Function to get the replacement for code.
getPercentReplacementHelp | Function to get the help text for the supported %-codes.
getProfileFileName | Function to build a file name for a profile data file.
getProfileFileNames | Function to build a list of profile data file names.
getSysPath | Module function to get the Python path (sys.path) of a specific interpreter.
getTestFileNames | Function to build the potential file names of a test file.
get_coding | Function to get the coding of a text.
get_codingBytes | Function to get the coding of a bytes text.
html_encode | Function to correctly encode a text for html.
html_udecode | Function to correctly decode a html text to a unicode text.
html_uencode | Function to correctly encode a unicode text for html.
linesep | Function to return the line separator used by the editor.
normalizeCode | Function to normalize the given code.
parseOptionString | Function used to convert an option string into a list of options.
readEncodedFile | Function to read a file and decode its contents into proper text.
readEncodedFileWithEncoding | Function to read a file and decode its contents into proper text.
readEncodedFileWithHash | Function to read a file, calculate a hash value and decode its contents into proper text.
readStringFromStream | Module function to read a string from the given stream.
rxIndex | Function to get the index (start position) of a regular expression match within some text.
unescape_uentities | Function to decode html entities.
writeEncodedFile | Function to write a file with properly encoded text.

## CodingError

Class implementing an exception, which is raised, if a given coding is incorrect.

### Derived from

Exception

### Class Attributes

None

### Class Methods

None

### Methods

CodingError | Constructor
__repr__ | Special method returning a representation of the exception.
__str__ | Special method returning a string representation of the exception.

### Static Methods

None

#### CodingError (Constructor)

CodingError(coding)

Constructor

coding
  coding to include in the message (string)

#### CodingError.__repr__

__repr__()

Special method returning a representation of the exception.

Return:
  string representing the error message

#### CodingError.__str__

__str__()

Special method returning a string representation of the exception.

Return:
  string representing the error message

Up

## __showwarning

__showwarning(message, category, filename, lineno, file=None, line="")

Module function to raise a SyntaxError for a SyntaxWarning.

message
  warning object
category
  type object of the warning
filename
  name of the file causing the warning (string)
lineno
  line number causing the warning (integer)
file
  file to write the warning message to (ignored)
line
  line causing the warning (ignored)

Raises err:
  exception of type SyntaxError

Up

## _percentReplacementFunc

_percentReplacementFunc(matchobj)

Protected function called for replacing % codes.

matchobj (re.Match)
  match object for the code

Return:
  replacement string

Return Type:
  str

Up

## convertLineEnds

convertLineEnds(text, eol)

Function to convert the end of line characters.

text
  text to be converted (string)
eol
  new eol setting (string)

Return:
  text with converted eols (string)

Up

## decode

decode(text)

Function to decode some byte text into a string.

text
  byte text to decode (bytes)

Return:
  tuple of decoded text and encoding (string, string)

Up

## decodeBytes

decodeBytes(buffer)

Function to decode some byte text into a string.

buffer
  byte buffer to decode (bytes)

Return:
  decoded text (string)

Up

## decodeString

decodeString(text)

Function to decode a string containing Unicode encoded characters.

text
  text containing encoded chars (string)

Return:
  decoded text (string)

Up

## encode

encode(text, origEncoding, forcedEncoding="")

Function to encode text into a byte text.

text (str)
  text to be encoded
origEncoding (str)
  type of the original encoding
forcedEncoding (str)
  encoding to be used for writing, if no coding line is present

Return:
  tuple of encoded text and encoding used

Return Type:
  tuple of (bytes, str)

Raises CodingError:
  raised to indicate an invalid encoding

Up

## escape_entities

escape_entities(m, escmap=_escape_map)

Function to encode html entities.

m
  the match object
escmap
  the map of entities to encode

Return:
  the converted text (string)

Up

## escape_uentities

escape_uentities(m)

Function to encode html entities.

m
  the match object

Return:
  the converted text (string)

Up

## extractFlags

extractFlags(text)

Function to extract eric specific flags out of the given text.

Flags are contained in comments and are introduced by 'eflag:'. The rest of the line is interpreted as 'key = value'. value is analyzed for being an integer or float value. If that fails, it is assumed to be a string. If a key does not contain a '=' character, it is assumed to be a boolean flag. Flags are expected at the very end of a file. The search is ended, if a line without the 'eflag:' marker is found.

text
  text to be scanned (string)

Return:
  dictionary of string, boolean, complex, float and int

Up

## extractFlagsFromFile

extractFlagsFromFile(filename)

Function to extract eric specific flags out of the given file.

filename
  name of the file to be scanned (string)

Return:
  dictionary of string, boolean, complex, float and int

Up

## extractLineFlags

extractLineFlags(line, startComment=")

Function to extract flags starting and ending with '__' from a line comment.

line
  line to extract flags from (string)
startComment
  string identifying the start of the comment (string)
endComment
  string identifying the end of a comment (string)
flagsLine
  flag indicating to check for a flags only line (bool)

Return:
  list containing the extracted flags (list of strings)

Up

## filterAnsiSequences

filterAnsiSequences(txt)

Function to filter out ANSI escape sequences (color only).

txt (str)
  text to be filtered

Return:
  text without ANSI escape sequences

Return Type:
  str

Up

## generateDistroInfo

generateDistroInfo(linesep="\n")

Module function to generate a string with distribution infos.

linesep (str)
  string to be used to separate lines

Return:
  string with distribution infos

Return Type:
  str

Up

## generatePluginsVersionInfo

generatePluginsVersionInfo(linesep="\n")

Module function to generate a string with plugins version infos.

linesep (str)
  string to be used to separate lines

Return:
  string with plugins version infos

Return Type:
  str

Up

## generateVersionInfo

generateVersionInfo(linesep="\n")

Module function to generate a string with various version infos.

linesep (str)
  string to be used to separate lines

Return:
  string with version infos

Return Type:
  str

Up

## getCoverageFileName

getCoverageFileName(fn, mustExist=True)

Function to build a file name for a coverage data file.

fn (str)
  file name basis to be used for the coverage data file name
mustExist (bool (optional))
  flag indicating to check that the file exists (defaults to True)

Return:
  coverage data file name

Return Type:
  str

Up

## getCoverageFileNames

getCoverageFileNames(fn)

Function to build a list of coverage data file names.

fn (str)
  file name basis to be used for the coverage data file

Return:
  list of existing coverage data files

Return Type:
  list of str

Up

## getPercentReplacement

getPercentReplacement(code)

Function to get the replacement for code.

code (str)
  code indicator

Return:
  replacement string

Return Type:
  str

Up

## getPercentReplacementHelp

getPercentReplacementHelp()

Function to get the help text for the supported %-codes.

Return:
  help text (string)

Up

## getProfileFileName

getProfileFileName(fn, mustExist=True)

Function to build a file name for a profile data file.

fn (str)
  file name basis to be used for the profile data file name
mustExist (bool (optional))
  flag indicating to check that the file exists (defaults to True)

Return:
  profile data file name

Return Type:
  str

Up

## getProfileFileNames

getProfileFileNames(fn)

Function to build a list of profile data file names.

fn (str)
  file name basis to be used for the profile data file

Return:
  list of existing profile data files

Return Type:
  list of str

Up

## getSysPath

getSysPath(interpreter)

Module function to get the Python path (sys.path) of a specific interpreter.

interpreter (str)
  Python interpreter executable to get sys.path for

Return:
  list containing sys.path of the interpreter; an empty list is returned, if the interpreter is the one used to run eric itself

Return Type:
  list of str

Up

## getTestFileNames

getTestFileNames(fn)

Function to build the potential file names of a test file.

The file names for the test file is built by prepending the string "test" and "test_" to the file name passed into this function and by appending the string "_test".

fn (str)
  file name basis to be used for the test file names

Return:
  file names of the corresponding test file

Return Type:
  list of str

Up

## get_coding

get_coding(text)

Function to get the coding of a text.

text
  text to inspect (string)

Return:
  coding string

Up

## get_codingBytes

get_codingBytes(text)

Function to get the coding of a bytes text.

text
  bytes text to inspect (bytes)

Return:
  coding string

Up

## html_encode

html_encode(text, pattern=_escape)

Function to correctly encode a text for html.

text
  text to be encoded (string)
pattern
  search pattern for text to be encoded (string)

Return:
  the encoded text (string)

Up

## html_udecode

html_udecode(text, pattern=_uunescape)

Function to correctly decode a html text to a unicode text.

text
  text to be decoded (string)
pattern
  search pattern for text to be decoded (string)

Return:
  the decoded text (string)

Up

## html_uencode

html_uencode(text, pattern=_uescape)

Function to correctly encode a unicode text for html.

text
  text to be encoded (string)
pattern
  search pattern for text to be encoded (string)

Return:
  the encoded text (string)

Up

## linesep

linesep()

Function to return the line separator used by the editor.

Return:
  line separator used by the editor (string)

Up

## normalizeCode

normalizeCode(codestring)

Function to normalize the given code.

codestring
  code to be normalized (string)

Return:
  normalized code (string)

Up

## parseOptionString

parseOptionString(s)

Function used to convert an option string into a list of options.

s (str)
  option string

Return:
  list of options

Return Type:
  list of str

Up

## readEncodedFile

readEncodedFile(filename)

Function to read a file and decode its contents into proper text.

filename
  name of the file to read (string)

Return:
  tuple of decoded text and encoding (string, string)

Up

## readEncodedFileWithEncoding

readEncodedFileWithEncoding(filename, encoding)

Function to read a file and decode its contents into proper text.

filename
  name of the file to read (string)
encoding
  encoding to be used to read the file (string)

Return:
  tuple of decoded text and encoding (string, string)

Up

## readEncodedFileWithHash

readEncodedFileWithHash(filename)

Function to read a file, calculate a hash value and decode its contents into proper text.

filename
  name of the file to read (string)

Return:
  tuple of decoded text, encoding and hash value (string, string, string)

Up

## readStringFromStream

readStringFromStream(stream)

Module function to read a string from the given stream.

stream
  data stream opened for reading (QDataStream)

Return:
  string read from the stream (string)

Up

## rxIndex

rxIndex(rx, txt)

Function to get the index (start position) of a regular expression match within some text.

rx (re.Pattern)
  regular expression object as created by re.compile()
txt (str)
  text to be scanned

Return:
  start position of the match or -1 indicating no match was found

Return Type:
  int

Up

## unescape_uentities

unescape_uentities(m)

Function to decode html entities.

m
  the match object

Return:
  the converted text (string)

Up

## writeEncodedFile

writeEncodedFile(filename, text, origEncoding, forcedEncoding="")

Function to write a file with properly encoded text.

filename (str)
  name of the file to read
text (str)
  text to be written
origEncoding (str)
  type of the original encoding
forcedEncoding (str)
  encoding to be used for writing, if no coding line is present

Return:
  encoding used for writing the file

Return Type:
  str

Up